New, updated, and deprecated options in Ocata for Block Storage
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

..
  Warning: Do not edit this file. It is automatically generated and your
  changes will be overwritten. The tool to do so lives in the
  openstack-doc-tools repository.

.. list-table:: New options
   :header-rows: 1
   :class: config-ref-table

   * - Option = default value
     - (Type) Help string
   * - ``[DEFAULT] auto_calc_max_oversubscription_ratio = False``
     - (BoolOpt) K2 driver will calculate max_oversubscription_ratio on setting this option as True.
   * - ``[DEFAULT] choice_client = None``
     - (StrOpt) Use soap client or rest client for communicating with DISCO. Possible values are "soap" or "rest".
   * - ``[DEFAULT] datera_tenant_id = None``
     - (StrOpt) If set to 'Map' --> OpenStack project ID will be mapped implicitly to Datera tenant ID If set to 'None' --> Datera tenant ID will not be used during volume provisioning If set to anything else --> Datera tenant ID will be the provided value
   * - ``[DEFAULT] disco_src_api_port = 8080``
     - (PortOpt) The port of DISCO source API
   * - ``[DEFAULT] ds8k_devadd_unitadd_mapping =``
     - (StrOpt) Mapping between IODevice address and unit address.
   * - ``[DEFAULT] ds8k_host_type = auto``
     - (StrOpt) Set to zLinux if your OpenStack version is prior to Liberty and you're connecting to zLinux systems. Otherwise set to auto. Valid values for this parameter are: 'auto', 'AMDLinuxRHEL', 'AMDLinuxSuse', 'AppleOSX', 'Fujitsu', 'Hp', 'HpTru64', 'HpVms', 'LinuxDT', 'LinuxRF', 'LinuxRHEL', 'LinuxSuse', 'Novell', 'SGI', 'SVC', 'SanFsAIX', 'SanFsLinux', 'Sun', 'VMWare', 'Win2000', 'Win2003', 'Win2008', 'Win2012', 'iLinux', 'nSeries', 'pLinux', 'pSeries', 'pSeriesPowerswap', 'zLinux', 'iSeries'.
   * - ``[DEFAULT] ds8k_ssid_prefix = FF``
     - (StrOpt) Set the first two digits of SSID
   * - ``[DEFAULT] fss_san_secondary_ip =``
     - (StrOpt) Specifies FSS secondary management IP to be used if san_ip is invalid or becomes inaccessible.
   * - ``[DEFAULT] hnas_svc0_pool_name = None``
     - (StrOpt) Service 0 pool name
   * - ``[DEFAULT] hnas_svc1_pool_name = None``
     - (StrOpt) Service 1 pool name
   * - ``[DEFAULT] hnas_svc2_pool_name = None``
     - (StrOpt) Service 2 pool name
   * - ``[DEFAULT] hnas_svc3_pool_name = None``
     - (StrOpt) Service 3 pool name:
   * - ``[DEFAULT] infinidat_pool_name = None``
     - (StrOpt) Name of the pool from which volumes are allocated
   * - ``[DEFAULT] multi_pool_support = False``
     - (StrOpt) Use this value to specify multi-pool support for VMAX3
   * - ``[DEFAULT] nec_actual_free_capacity = False``
     - (BoolOpt) Return actual free capacity.
   * - ``[DEFAULT] nec_backend_max_ld_count = 1024``
     - (IntOpt) Maximum number of managing sessions.
   * - ``[DEFAULT] nec_backup_ldname_format = LX:%s``
     - (StrOpt) M-Series Storage LD name format for snapshots.
   * - ``[DEFAULT] nec_backup_pools =``
     - (ListOpt) M-Series Storage backup pool number to be used.
   * - ``[DEFAULT] nec_diskarray_name =``
     - (StrOpt) Diskarray name of M-Series Storage.
   * - ``[DEFAULT] nec_iscsi_portals_per_cont = 1``
     - (IntOpt) Number of iSCSI portals.
   * - ``[DEFAULT] nec_ismcli_fip = None``
     - (IPOpt) FIP address of M-Series Storage iSMCLI.
   * - ``[DEFAULT] nec_ismcli_password =``
     - (StrOpt) Password for M-Series Storage iSMCLI.
   * - ``[DEFAULT] nec_ismcli_privkey =``
     - (StrOpt) Filename of RSA private key for M-Series Storage iSMCLI.
   * - ``[DEFAULT] nec_ismcli_user =``
     - (StrOpt) User name for M-Series Storage iSMCLI.
   * - ``[DEFAULT] nec_ismview_alloptimize = False``
     - (BoolOpt) Use legacy iSMCLI command with optimization.
   * - ``[DEFAULT] nec_ismview_dir = /tmp/nec/cinder``
     - (StrOpt) Output path of iSMview file.
   * - ``[DEFAULT] nec_ldname_format = LX:%s``
     - (StrOpt) M-Series Storage LD name format for volumes.
   * - ``[DEFAULT] nec_ldset =``
     - (StrOpt) M-Series Storage LD Set name for Compute Node.
   * - ``[DEFAULT] nec_ldset_for_controller_node =``
     - (StrOpt) M-Series Storage LD Set name for Controller Node.
   * - ``[DEFAULT] nec_pools =``
     - (ListOpt) M-Series Storage pool numbers list to be used.
   * - ``[DEFAULT] nec_queryconfig_view = False``
     - (BoolOpt) Use legacy iSMCLI command.
   * - ``[DEFAULT] nec_ssh_pool_port_number = 22``
     - (IntOpt) Port number of ssh pool.
   * - ``[DEFAULT] nec_unpairthread_timeout = 3600``
     - (IntOpt) Timeout value of Unpairthread.
   * - ``[DEFAULT] nexenta_use_https = True``
     - (BoolOpt) Use secure HTTP for REST connection (default True)
   * - ``[DEFAULT] nfs_qcow2_volumes = False``
     - (BoolOpt) Create volumes as QCOW2 files rather than raw files.
   * - ``[DEFAULT] nfs_snapshot_support = False``
     - (BoolOpt) Enable support for snapshots on the NFS driver. Platforms using libvirt <1.2.7 will encounter issues with this feature.
   * - ``[DEFAULT] nimble_verify_cert_path = None``
     - (StrOpt) Path to Nimble Array SSL certificate
   * - ``[DEFAULT] nimble_verify_certificate = False``
     - (StrOpt) Whether to verify Nimble SSL Certificate
   * - ``[DEFAULT] nova_api_insecure = False``
     - (BoolOpt) Allow to perform insecure SSL requests to nova
   * - ``[DEFAULT] nova_ca_certificates_file = None``
     - (StrOpt) Location of ca certificates file to use for nova client requests.
   * - ``[DEFAULT] nova_catalog_admin_info = compute:Compute Service:adminURL``
     - (StrOpt) Same as nova_catalog_info, but for admin endpoint.
   * - ``[DEFAULT] nova_catalog_info = compute:Compute Service:publicURL``
     - (StrOpt) Match this value when searching for nova in the service catalog. Format is: separated values of the form: <service_type>:<service_name>:<endpoint_type>
   * - ``[DEFAULT] nova_endpoint_admin_template = None``
     - (StrOpt) Same as nova_endpoint_template, but for admin endpoint.
   * - ``[DEFAULT] nova_endpoint_template = None``
     - (StrOpt) Override service catalog lookup with template for nova endpoint e.g. http://localhost:8774/v2/%(project_id)s
   * - ``[DEFAULT] os_region_name = None``
     - (StrOpt) Region name of this node
   * - ``[DEFAULT] qnap_management_url = None``
     - (URIOpt) The URL to management QNAP Storage
   * - ``[DEFAULT] qnap_poolname = None``
     - (StrOpt) The pool name in the QNAP Storage
   * - ``[DEFAULT] qnap_storage_protocol = iscsi``
     - (StrOpt) Communication protocol to access QNAP storage
   * - ``[DEFAULT] replication_connect_timeout = 5``
     - (IntOpt) Timeout value (in seconds) used when connecting to ceph cluster to do a demotion/promotion of volumes. If value < 0, no timeout is set and default librados value is used.
   * - ``[DEFAULT] rest_ip = None``
     - (IPOpt) The IP address of the REST server
   * - ``[DEFAULT] unity_io_ports = None``
     - (ListOpt) A comma-separated list of iSCSI or FC ports to be used. Each port can be Unix-style glob expressions.
   * - ``[DEFAULT] unity_storage_pool_names = None``
     - (ListOpt) A comma-separated list of storage pool names to be used.
   * - ``[DEFAULT] vmware_connection_pool_size = 10``
     - (IntOpt) Maximum number of connections in http connection pool.
   * - ``[DEFAULT] vsp_async_copy_check_interval = 10``
     - (IntOpt) Interval in seconds at which volume pair synchronization status is checked when volume pairs are deleted.
   * - ``[DEFAULT] vsp_auth_password = None``
     - (StrOpt) Password corresponding to vsp_auth_user.
   * - ``[DEFAULT] vsp_auth_user = None``
     - (StrOpt) Name of the user used for CHAP authentication performed in communication between hosts and iSCSI targets on the storage ports.
   * - ``[DEFAULT] vsp_compute_target_ports = None``
     - (ListOpt) IDs of the storage ports used to attach volumes to compute nodes. To specify multiple ports, connect them by commas (e.g. CL1-A,CL2-A).
   * - ``[DEFAULT] vsp_copy_check_interval = 3``
     - (IntOpt) Interval in seconds at which volume pair synchronization status is checked when volume pairs are created.
   * - ``[DEFAULT] vsp_copy_speed = 3``
     - (IntOpt) Speed at which data is copied by Shadow Image. 1 or 2 indicates low speed, 3 indicates middle speed, and a value between 4 and 15 indicates high speed.
   * - ``[DEFAULT] vsp_default_copy_method = FULL``
     - (StrOpt) Method of volume copy. FULL indicates full data copy by Shadow Image and THIN indicates differential data copy by Thin Image.
   * - ``[DEFAULT] vsp_group_request = False``
     - (BoolOpt) If True, the driver will create host groups or iSCSI targets on storage ports as needed.
   * - ``[DEFAULT] vsp_horcm_add_conf = True``
     - (BoolOpt) If True, the driver will create or update the Command Control Interface configuration file as needed.
   * - ``[DEFAULT] vsp_horcm_numbers = 200, 201``
     - (ListOpt) Command Control Interface instance numbers in the format of 'xxx,yyy'. The second one is for Shadow Image operation and the first one is for other purposes.
   * - ``[DEFAULT] vsp_horcm_pair_target_ports = None``
     - (ListOpt) IDs of the storage ports used to copy volumes by Shadow Image or Thin Image. To specify multiple ports, connect them by commas (e.g. CL1-A,CL2-A).
   * - ``[DEFAULT] vsp_horcm_password = None``
     - (StrOpt) Password corresponding to vsp_horcm_user.
   * - ``[DEFAULT] vsp_horcm_user = None``
     - (StrOpt) Name of the user on the storage system.
   * - ``[DEFAULT] vsp_ldev_range = None``
     - (StrOpt) Range of the LDEV numbers in the format of 'xxxx-yyyy' that can be used by the driver. Values can be in decimal format (e.g. 1000) or in colon-separated hexadecimal format (e.g. 00:03:E8).
   * - ``[DEFAULT] vsp_pool = None``
     - (StrOpt) Pool number or pool name of the DP pool.
   * - ``[DEFAULT] vsp_storage_id = None``
     - (StrOpt) Product number of the storage system.
   * - ``[DEFAULT] vsp_target_ports = None``
     - (ListOpt) IDs of the storage ports used to attach volumes to the controller node. To specify multiple ports, connect them by commas (e.g. CL1-A,CL2-A).
   * - ``[DEFAULT] vsp_thin_pool = None``
     - (StrOpt) Pool number or pool name of the Thin Image pool.
   * - ``[DEFAULT] vsp_use_chap_auth = False``
     - (BoolOpt) If True, CHAP authentication will be applied to communication between hosts and any of the iSCSI targets on the storage ports.
   * - ``[DEFAULT] vsp_zoning_request = False``
     - (BoolOpt) If True, the driver will configure FC zoning between the server and the storage system provided that FC zoning manager is enabled.

.. list-table:: New default values
   :header-rows: 1
   :class: config-ref-table

   * - Option
     - Previous default value
     - New default value
   * - ``[DEFAULT] enable_v1_api``
     - ``True``
     - ``False``
   * - ``[DEFAULT] nexenta_rest_port``
     - ``8080``
     - ``0``
   * - ``[DEFAULT] proxy``
     - ``storage.proxy.IBMStorageProxy``
     - ``cinder.volume.drivers.ibm.ibm_storage.proxy.IBMStorageProxy``

.. list-table:: Deprecated options
   :header-rows: 1
   :class: config-ref-table

   * - Deprecated option
     - New Option
   * - ``[DEFAULT] enable_v1_api``
     - ``None``
   * - ``[DEFAULT] enable_v2_api``
     - ``None``
   * - ``[DEFAULT] hnas_svc0_volume_type``
     - ``[DEFAULT] hnas_svc0_pool_name``
   * - ``[DEFAULT] hnas_svc1_volume_type``
     - ``[DEFAULT] hnas_svc1_pool_name``
   * - ``[DEFAULT] hnas_svc2_volume_type``
     - ``[DEFAULT] hnas_svc2_pool_name``
   * - ``[DEFAULT] hnas_svc3_volume_type``
     - ``[DEFAULT] hnas_svc3_pool_name``
   * - ``[DEFAULT] host``
     - ``[DEFAULT] backend_host``
   * - ``[DEFAULT] osapi_max_request_body_size``
     - ``[oslo_middleware] max_request_body_size``
   * - ``[DEFAULT] rpc_thread_pool_size``
     - ``[DEFAULT] executor_thread_pool_size``
   * - ``[DEFAULT] use_syslog``
     - ``None``
   * - ``[hyperv] force_volumeutils_v1``
     - ``None``

